# -*- coding: utf-8 -*-
# @Time    : 2018/4/29 15:28
# @Author  : play4fun
# @File    : config.py
# @Software: PyCharm

"""
config.py:
"""

#大星发星东网
appkey = "24728341"
secret = "b29db0fb6fd58bf51be896035e5d8f69"


#绘读
appkey2 = "24728514"
secret2 = "847aff038c548e44adeeb7fd634d6cc2"