#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name='topsdk',
    version='18.11.18',#按日期
    author='top',
    author_email='xuteng.xt@alibaba-inc.com',
    packages=find_packages(),
    install_requires=[],
    license='MIT',
)

